from setuptools import setup, find_packages

setup(
    name='MySmallSite-temp',
    version='0.0.2',
    description='https://github.com/H-E1P/MySmallSite/pull/1#issuecomment-2594588147',
    author='c0dk1ddy',
    author_email='tax0787bz3@gmail.com',
    url='https://github.com/c0dk1ddy/MySmallSitePR',
    install_requires=[],
    packages=find_packages(exclude=[]),
    keywords=['mss tempertal'],
    python_requires='>=3.5',
    package_data={},
    zip_safe=False,
    classifiers=[
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Programming Language :: Python :: 3.10',
        'Programming Language :: Python :: 3.11',
        'Programming Language :: Python :: 3.12',
    ],
)
